# AI Platform One-time Login Python Library 
This Python library/CLI is a tool for AI Platform users to login to AI Platform services. With this tool, users only need to log in once to use all AI Platform services.

## Installation
For master branch
```
pip install git+https://
```

## Support
For any AI Platform issues (including questions, feedback, and feature requests):
* Reach out to us on our Slack channel: [#eadp-data-ai-platform-support](https://electronic-arts.slack.com/archives/CG2CK8XEY).
  * Preface your message with the service name, in this case: **For AIP Login:**.
* Send emails to [EADPAIOncall@ea.com](mailto:EADPAIOncall@ea.com?subject=For AXS:).
  * Preface your subject line with the service name, in this case: **For AIP Login:**.



